@@ -19,9 +19,7 @@ use crate::{
 };
 
 macro_rules! err {
-	() => {{
-		::std::result::Result::Err(::nom::Err::Error($crate::engine::error::Dummy))
-	}};
+	[] => (::std::result::Result::Err(::nom::Err::Error($crate::engine::error::Dummy)));
 }
 pub(crate) use err;
 
@@ -30,16 +28,16 @@ enum MatchResult<'c, 't> {
 	Many(Vec<(&'c str, Match<'t>)>),
 }
 
-impl<'c, 't> Command {
+impl Command {
 	/// Match this [Command] to the given text, returning captures if any.
-	pub fn get_matches(&'c self, s: &'t str) -> Option<Args<'c, 't>> {
+	pub fn get_matches<'c, 't>(&'c self, s: &'t str) -> Option<Args<'c, 't>> {
 		Segments(self.0.as_slice()).get_matches(s)
 	}
 
 	/// Returns true if the command matches the string at least partially.
 	/// This is equivalent to a command composed of only the first [Segment] of
 	/// `self` matching the string and checking that it is `Some`.
-	/// ##### Examples
+	/// #### Examples
 	/// ```rust
 	/// let cmd = malachi::Command::new("?eval <code: starts('```'), ends('```')>")?;
 	///
@@ -51,7 +49,7 @@ impl<'c, 't> Command {
 	/// # Ok::<(), malachi::Error>(())
 	/// ```
 	pub fn has_prefix(&self, s: &str) -> bool {
-		Segments(&self.0[..1]).get_matches(s).is_some()
+		!self.0.is_empty() && Segments(&self.0[..1]).get_matches(s).is_some()
 	}
 }
 
